@@ -1,6 +1,6 @@
 import functools
 from collections.abc import Callable
-from typing import Protocol, TypeVar
+from typing import Protocol
 
 __all__ = [
     "identity",
@@ -11,12 +11,8 @@ __all__ = [
     "unique_returns",
 ]
 
-T = TypeVar("T")
-U = TypeVar("U")
-RT = TypeVar("RT")
 
-
-def identity(instance: T) -> T:
+def identity[T](instance: T) -> T:
     """
     Returns the input ``instance`` unchanged. This is a utility function often used as a default or placeholder.
 
@@ -26,22 +22,19 @@ def identity(instance: T) -> T:
     return instance
 
 
-class Composable(Protocol[T, RT]):
+class Composable[T, R](Protocol):
     """
     Protocol for composable callables, supporting composition and chaining with other callables.
-
-    :param x: The input value for the callable.
-    :return: The result of the callable.
     """
 
-    def __call__(self, x: T) -> RT: ...
+    def __call__(self, x: T) -> R: ...
 
-    def compose(self, func: "Callable[[U], T] | Composable[U, T]") -> "Composable[U, RT]": ...
+    def compose[U](self, func: "Callable[[U], T] | Composable[U, T]") -> "Composable[U, R]": ...
 
-    def and_then(self, func: "Callable[[RT], U] | Composable[RT, U]") -> "Composable[T, U]": ...
+    def and_then[U](self, func: "Callable[[R], U] | Composable[R, U]") -> "Composable[T, U]": ...
 
 
-def composable(func: Callable[[T], RT]) -> Composable[T, RT]:
+def composable[T, R](func: Callable[[T], R]) -> Composable[T, R]:
     """
     Wraps a function to make it composable, allowing chaining with compose and and_then methods.
 
@@ -49,13 +42,13 @@ def composable(func: Callable[[T], RT]) -> Composable[T, RT]:
     :return: A composable version of the function.
     """
 
-    def compose(another_func: Callable[[U], T] | Composable[U, T]) -> Composable[U, RT]:
-        def chained(x: U) -> RT:
+    def compose[U](another_func: Callable[[U], T] | Composable[U, T]) -> Composable[U, R]:
+        def chained(x: U) -> R:
             return func(another_func(x))
 
         return composable(chained)
 
-    def and_then(another_func: Callable[[RT], U] | Composable[RT, U]) -> Composable[T, U]:
+    def and_then[U](another_func: Callable[[R], U] | Composable[R, U]) -> Composable[T, U]:
         def chained(x: T) -> U:
             return another_func(func(x))
 
@@ -66,7 +59,7 @@ def composable(func: Callable[[T], RT]) -> Composable[T, RT]:
     return func
 
 
-def singleton(tar: Callable[..., RT] = None):
+def singleton[R](tar: Callable[..., R] = None):
     """
     Decorator to ensure a function or class is only instantiated once. Subsequent calls return the same instance.
 
@@ -91,7 +84,7 @@ def singleton(tar: Callable[..., RT] = None):
     return decorator if tar is None else decorator(tar)
 
 
-def memorized(tar: Callable[..., RT] = None, *, ordered: bool = False, typed: bool = False):
+def memorized[R](tar: Callable[..., R] = None, *, ordered: bool = False, typed: bool = False):
     """
     Decorator to cache the results of a function based on its arguments. Supports options for argument order and type.
 
@@ -134,7 +127,7 @@ def memorized(tar: Callable[..., RT] = None, *, ordered: bool = False, typed: bo
     return decorator if tar is None else decorator(tar)
 
 
-def lazy(tar: Callable[..., RT] = None):
+def lazy[R](tar: Callable[..., R] = None):
     """
     Decorator to defer the execution of a function until its result is explicitly requested.
 
@@ -155,7 +148,7 @@ def lazy(tar: Callable[..., RT] = None):
     return decorator if tar is None else decorator(tar)
 
 
-def unique_returns(tar: Callable[..., RT] = None, *, max_trials: int | None = None):
+def unique_returns[R](tar: Callable[..., R] = None, *, max_trials: int | None = None):
     """
     Decorator to ensure a function produces unique return values. If no unique value is found within max_trials,
     raises an error.
