@@ -1,12 +1,6 @@
 import math
-import sys
 from collections.abc import Callable, Mapping, MutableMapping, MutableSequence, Sequence, Set
-from typing import Any, SupportsFloat, SupportsInt, TypeAlias
-
-if sys.version_info < (3, 12):
-    from typing_extensions import TypeAliasType
-else:
-    from typing import TypeAliasType
+from typing import Any, SupportsFloat, SupportsInt
 
 from iker.common.utils.numutils import is_normal_real
 
@@ -35,28 +29,26 @@ __all__ = [
 
 JsonKey = str
 JsonValue = str | bool | float | int | None
-JsonObject: TypeAlias = TypeAliasType("JsonObject", "dict[JsonKey, JsonType]")
-JsonArray: TypeAlias = TypeAliasType("JsonArray", "list[JsonType]")
-JsonType: TypeAlias = TypeAliasType("JsonType", "JsonValue | JsonObject | JsonArray")
+type JsonObject = dict[JsonKey, JsonType]
+type JsonArray = list[JsonType]
+type JsonType = JsonValue | JsonObject | JsonArray
+
 JsonKeyCompatible = str
 JsonValueCompatible = str | bool | SupportsFloat | SupportsInt | None
-JsonObjectCompatible: TypeAlias = TypeAliasType("JsonObjectCompatible",
-                                                "Mapping[JsonKeyCompatible, JsonTypeCompatible]")
-JsonArrayCompatible: TypeAlias = TypeAliasType("JsonArrayCompatible",
-                                               "Sequence[JsonTypeCompatible]")
-JsonTypeCompatible: TypeAlias = TypeAliasType("JsonTypeCompatible",
-                                              "JsonValueCompatible | JsonObjectCompatible | JsonArrayCompatible")
+type JsonObjectCompatible = Mapping[JsonKeyCompatible, JsonTypeCompatible]
+type JsonArrayCompatible = Sequence[JsonTypeCompatible]
+type JsonTypeCompatible = JsonValueCompatible | JsonObjectCompatible | JsonArrayCompatible
 
 
 class NodeAsterisk(object):
     pass
 
 
-Node = str | int | NodeAsterisk
-NodePath: TypeAlias = TypeAliasType("NodePath", "list[Node]")
-
 asterisk = NodeAsterisk()
 
+Node = str | int | NodeAsterisk
+type NodePath = list[Node]
+
 
 def json_get(
     obj: JsonTypeCompatible,
