@@ -6,12 +6,11 @@ from decimal import Decimal
 import pytest
 import pytest_mysql.factories
 import pytest_postgresql.factories
+import sqlalchemy as sa
 import sqlalchemy.dialects.mysql as sa_mysql
 import sqlalchemy.dialects.postgresql as sa_pg
-import sqlalchemy.orm
-from sqlalchemy.exc import IntegrityError
-from sqlalchemy.orm import DeclarativeBase, Mapped, MappedAsDataclass
-from sqlalchemy.orm.exc import FlushError
+import sqlalchemy.exc as sa_exc
+import sqlalchemy.orm as sa_orm
 
 from iker.common.utils.dbutils import ConnectionMaker, Dialects, Drivers
 from iker.common.utils.dbutils import make_scheme
@@ -29,83 +28,83 @@ fixture_postgresql_test_proc = pytest_postgresql.factories.postgresql_proc(host=
 fixture_postgresql_test = pytest_postgresql.factories.postgresql("fixture_postgresql_test_proc", dbname="test")
 
 
-class MysqlBaseModel(MappedAsDataclass, DeclarativeBase):
+class MysqlBaseModel(sa_orm.MappedAsDataclass, sa_orm.DeclarativeBase):
     pass
 
 
-class PostgresqlBaseModel(MappedAsDataclass, DeclarativeBase):
+class PostgresqlBaseModel(sa_orm.MappedAsDataclass, sa_orm.DeclarativeBase):
     pass
 
 
 class MysqlDummyRecord(MysqlBaseModel):
     __tablename__ = "mysql_dummy_record"
 
-    dummy_id: Mapped[int] = sqlalchemy.orm.mapped_column(sa_mysql.BIGINT,
-                                                         primary_key=True,
-                                                         autoincrement=True,
-                                                         index=True,
-                                                         unique=True,
-                                                         init=False)
-    dummy_char: Mapped[str] = sqlalchemy.orm.mapped_column(sa_mysql.CHAR(31))
-    dummy_varchar: Mapped[str] = sqlalchemy.orm.mapped_column(sa_mysql.VARCHAR(31))
-    dummy_text: Mapped[str] = sqlalchemy.orm.mapped_column(sa_mysql.TEXT)
-    dummy_boolean: Mapped[bool] = sqlalchemy.orm.mapped_column(sa_mysql.BOOLEAN)
-    dummy_smallint: Mapped[int] = sqlalchemy.orm.mapped_column(sa_mysql.SMALLINT)
-    dummy_integer: Mapped[int] = sqlalchemy.orm.mapped_column(sa_mysql.INTEGER)
-    dummy_bigint: Mapped[int] = sqlalchemy.orm.mapped_column(sa_mysql.BIGINT)
-    dummy_float: Mapped[float] = sqlalchemy.orm.mapped_column(sa_mysql.FLOAT)
-    dummy_double: Mapped[Decimal] = sqlalchemy.orm.mapped_column(sa_mysql.DOUBLE)
-    dummy_date: Mapped[datetime.date] = sqlalchemy.orm.mapped_column(sa_mysql.DATE)
-    dummy_time: Mapped[datetime.time] = sqlalchemy.orm.mapped_column(sa_mysql.TIME)
-    dummy_datetime: Mapped[datetime.datetime] = sqlalchemy.orm.mapped_column(sa_mysql.DATETIME)
-    dummy_json: Mapped[object] = sqlalchemy.orm.mapped_column(sa_mysql.JSON)
-    dummy_unique_string: Mapped[str] = sqlalchemy.orm.mapped_column(sa_mysql.VARCHAR(15), unique=True)
+    dummy_id: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_mysql.BIGINT,
+                                                        primary_key=True,
+                                                        autoincrement=True,
+                                                        index=True,
+                                                        unique=True,
+                                                        init=False)
+    dummy_char: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_mysql.CHAR(31))
+    dummy_varchar: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_mysql.VARCHAR(31))
+    dummy_text: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_mysql.TEXT)
+    dummy_boolean: sa_orm.Mapped[bool] = sa_orm.mapped_column(sa_mysql.BOOLEAN)
+    dummy_smallint: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_mysql.SMALLINT)
+    dummy_integer: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_mysql.INTEGER)
+    dummy_bigint: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_mysql.BIGINT)
+    dummy_float: sa_orm.Mapped[float] = sa_orm.mapped_column(sa_mysql.FLOAT)
+    dummy_double: sa_orm.Mapped[Decimal] = sa_orm.mapped_column(sa_mysql.DOUBLE)
+    dummy_date: sa_orm.Mapped[datetime.date] = sa_orm.mapped_column(sa_mysql.DATE)
+    dummy_time: sa_orm.Mapped[datetime.time] = sa_orm.mapped_column(sa_mysql.TIME)
+    dummy_datetime: sa_orm.Mapped[datetime.datetime] = sa_orm.mapped_column(sa_mysql.DATETIME)
+    dummy_json: sa_orm.Mapped[object] = sa_orm.mapped_column(sa_mysql.JSON)
+    dummy_unique_string: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_mysql.VARCHAR(15), unique=True)
 
     __table_args__ = (
-        sqlalchemy.Index("index_mysql_dummy_record",
-                         dummy_boolean,
-                         dummy_smallint,
-                         dummy_integer,
-                         dummy_bigint,
-                         unique=True),
+        sa.Index("index_mysql_dummy_record",
+                 dummy_boolean,
+                 dummy_smallint,
+                 dummy_integer,
+                 dummy_bigint,
+                 unique=True),
     )
 
 
 class PostgresqlDummyRecord(PostgresqlBaseModel):
     __tablename__ = "postgresql_dummy_record"
 
-    dummy_id: Mapped[int] = sqlalchemy.orm.mapped_column(sa_pg.BIGINT,
-                                                         primary_key=True,
-                                                         autoincrement=True,
-                                                         index=True,
-                                                         unique=True,
-                                                         init=False)
-    dummy_char: Mapped[str] = sqlalchemy.orm.mapped_column(sa_pg.CHAR(31))
-    dummy_varchar: Mapped[str] = sqlalchemy.orm.mapped_column(sa_pg.VARCHAR(31))
-    dummy_text: Mapped[str] = sqlalchemy.orm.mapped_column(sa_pg.TEXT)
-    dummy_boolean: Mapped[bool] = sqlalchemy.orm.mapped_column(sa_pg.BOOLEAN)
-    dummy_smallint: Mapped[int] = sqlalchemy.orm.mapped_column(sa_pg.SMALLINT)
-    dummy_integer: Mapped[int] = sqlalchemy.orm.mapped_column(sa_pg.INTEGER)
-    dummy_bigint: Mapped[int] = sqlalchemy.orm.mapped_column(sa_pg.BIGINT)
-    dummy_float: Mapped[float] = sqlalchemy.orm.mapped_column(sa_pg.FLOAT)
-    dummy_double_precision: Mapped[float] = sqlalchemy.orm.mapped_column(sa_pg.DOUBLE_PRECISION)
-    dummy_date: Mapped[datetime.date] = sqlalchemy.orm.mapped_column(sa_pg.DATE)
-    dummy_time: Mapped[datetime.time] = sqlalchemy.orm.mapped_column(sa_pg.TIME)
-    dummy_time_tz: Mapped[datetime.time] = sqlalchemy.orm.mapped_column(sa_pg.TIME(timezone=True))
-    dummy_timestamp: Mapped[datetime.datetime] = sqlalchemy.orm.mapped_column(sa_pg.TIMESTAMP)
-    dummy_timestamp_tz: Mapped[datetime.datetime] = sqlalchemy.orm.mapped_column(sa_pg.TIMESTAMP(timezone=True))
-    dummy_array_varchar: Mapped[list[str]] = sqlalchemy.orm.mapped_column(sa_pg.ARRAY(sa_pg.VARCHAR(31)))
-    dummy_jsonb: Mapped[object] = sqlalchemy.orm.mapped_column(sa_pg.JSONB)
-    dummy_json: Mapped[object] = sqlalchemy.orm.mapped_column(sa_pg.JSON)
-    dummy_unique_string: Mapped[str] = sqlalchemy.orm.mapped_column(sa_pg.VARCHAR(15), unique=True)
+    dummy_id: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_pg.BIGINT,
+                                                        primary_key=True,
+                                                        autoincrement=True,
+                                                        index=True,
+                                                        unique=True,
+                                                        init=False)
+    dummy_char: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_pg.CHAR(31))
+    dummy_varchar: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_pg.VARCHAR(31))
+    dummy_text: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_pg.TEXT)
+    dummy_boolean: sa_orm.Mapped[bool] = sa_orm.mapped_column(sa_pg.BOOLEAN)
+    dummy_smallint: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_pg.SMALLINT)
+    dummy_integer: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_pg.INTEGER)
+    dummy_bigint: sa_orm.Mapped[int] = sa_orm.mapped_column(sa_pg.BIGINT)
+    dummy_float: sa_orm.Mapped[float] = sa_orm.mapped_column(sa_pg.FLOAT)
+    dummy_double_precision: sa_orm.Mapped[float] = sa_orm.mapped_column(sa_pg.DOUBLE_PRECISION)
+    dummy_date: sa_orm.Mapped[datetime.date] = sa_orm.mapped_column(sa_pg.DATE)
+    dummy_time: sa_orm.Mapped[datetime.time] = sa_orm.mapped_column(sa_pg.TIME)
+    dummy_time_tz: sa_orm.Mapped[datetime.time] = sa_orm.mapped_column(sa_pg.TIME(timezone=True))
+    dummy_timestamp: sa_orm.Mapped[datetime.datetime] = sa_orm.mapped_column(sa_pg.TIMESTAMP)
+    dummy_timestamp_tz: sa_orm.Mapped[datetime.datetime] = sa_orm.mapped_column(sa_pg.TIMESTAMP(timezone=True))
+    dummy_array_varchar: sa_orm.Mapped[list[str]] = sa_orm.mapped_column(sa_pg.ARRAY(sa_pg.VARCHAR(31)))
+    dummy_jsonb: sa_orm.Mapped[object] = sa_orm.mapped_column(sa_pg.JSONB)
+    dummy_json: sa_orm.Mapped[object] = sa_orm.mapped_column(sa_pg.JSON)
+    dummy_unique_string: sa_orm.Mapped[str] = sa_orm.mapped_column(sa_pg.VARCHAR(15), unique=True)
 
     __table_args__ = (
-        sqlalchemy.Index("index_postgresql_dummy_record",
-                         dummy_boolean,
-                         dummy_smallint,
-                         dummy_integer,
-                         dummy_bigint,
-                         unique=True),
+        sa.Index("index_postgresql_dummy_record",
+                 dummy_boolean,
+                 dummy_smallint,
+                 dummy_integer,
+                 dummy_bigint,
+                 unique=True),
     )
 
 
@@ -152,7 +151,7 @@ def test_mysql_connection_maker(fixture_mysql_test_proc, fixture_mysql_test):
         session.commit()
 
     with maker.make_session() as session:
-        count = session.query(sqlalchemy.func.count()).select_from(MysqlDummyRecord).scalar()
+        count = session.query(sa.func.count()).select_from(MysqlDummyRecord).scalar()
 
     assert count == 1000
 
@@ -163,7 +162,7 @@ def test_mysql_connection_maker(fixture_mysql_test_proc, fixture_mysql_test):
         session.commit()
 
     with maker.make_session() as session:
-        count = session.query(sqlalchemy.func.count()).select_from(MysqlDummyRecord).scalar()
+        count = session.query(sa.func.count()).select_from(MysqlDummyRecord).scalar()
 
     assert count == 500
 
@@ -204,13 +203,13 @@ def test_mysql_connection_maker(fixture_mysql_test_proc, fixture_mysql_test):
 
     with maker.make_session() as session:
         # PK violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             session.add(orm_clone(result))
             session.commit()
 
     with maker.make_session() as session:
         # Unique index violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             session.add(orm_clone(result, no_autoincrement=True))
             session.commit()
 
@@ -282,8 +281,8 @@ def test_mysql_connection_maker__sql_text(fixture_mysql_test_proc, fixture_mysql
         WHERE `dummy_id` IN (SELECT `dummy_id`
                              FROM (SELECT `dummy_id`
                                    FROM `mysql_dummy_record`
-                                   ORDER BY `dummy_id`
-                                   LIMIT 1000 OFFSET :offset) AS `subquery`)
+                                   ORDER BY `dummy_id` LIMIT 1000
+                                   OFFSET :offset) AS `subquery`)
         """,
         offset=500,
     )
@@ -330,7 +329,8 @@ def test_mysql_connection_maker__sql_text(fixture_mysql_test_proc, fixture_mysql
     maker.execute(
         # language=mysql
         """
-        INSERT IGNORE INTO `mysql_dummy_record` (`dummy_id`,
+        INSERT
+        IGNORE INTO `mysql_dummy_record` (`dummy_id`,
                                                  `dummy_char`,
                                                  `dummy_varchar`,
                                                  `dummy_text`,
@@ -382,7 +382,8 @@ def test_mysql_connection_maker__sql_text(fixture_mysql_test_proc, fixture_mysql
     maker.execute(
         # language=mysql
         """
-        INSERT IGNORE INTO `mysql_dummy_record` (`dummy_char`,
+        INSERT
+        IGNORE INTO `mysql_dummy_record` (`dummy_char`,
                                                  `dummy_varchar`,
                                                  `dummy_text`,
                                                  `dummy_boolean`,
@@ -429,7 +430,7 @@ def test_mysql_connection_maker__sql_text(fixture_mysql_test_proc, fixture_mysql
 
     with maker.make_session() as session:
         # PK violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             maker.execute(
                 # language=mysql
                 """
@@ -483,7 +484,7 @@ def test_mysql_connection_maker__sql_text(fixture_mysql_test_proc, fixture_mysql
 
     with maker.make_session() as session:
         # Unique index violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             maker.execute(
                 # language=mysql
                 """
@@ -582,7 +583,7 @@ def test_postgresql_connection_maker(fixture_postgresql_test_proc, fixture_postg
         session.commit()
 
     with maker.make_session() as session:
-        count = session.query(sqlalchemy.func.count()).select_from(PostgresqlDummyRecord).scalar()
+        count = session.query(sa.func.count()).select_from(PostgresqlDummyRecord).scalar()
 
     assert count == 1000
 
@@ -593,7 +594,7 @@ def test_postgresql_connection_maker(fixture_postgresql_test_proc, fixture_postg
         session.commit()
 
     with maker.make_session() as session:
-        count = session.query(sqlalchemy.func.count()).select_from(PostgresqlDummyRecord).scalar()
+        count = session.query(sa.func.count()).select_from(PostgresqlDummyRecord).scalar()
 
     assert count == 500
 
@@ -633,19 +634,19 @@ def test_postgresql_connection_maker(fixture_postgresql_test_proc, fixture_postg
             # Unique index violation, but suppressed by the compiler plugin
             # However, since insertion is not performed, it fails to return and
             # flush the auto-generated primary key of the ORM, which raises ``FlushError``
-            with pytest.raises(FlushError):
+            with pytest.raises(sa_orm.exc.FlushError):
                 session.add(orm_clone(result, no_autoincrement=True))
                 session.commit()
 
     with maker.make_session() as session:
         # PK violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             session.add(orm_clone(result))
             session.commit()
 
     with maker.make_session() as session:
         # Unique index violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             session.add(orm_clone(result, no_autoincrement=True))
             session.commit()
 
@@ -802,8 +803,7 @@ def test_postgresql_connection_maker__sql_text(fixture_postgresql_test_proc, fix
                 :dummy_array_varchar,
                 :dummy_jsonb,
                 :dummy_json,
-                :dummy_unique_string)
-        ON CONFLICT
+                :dummy_unique_string) ON CONFLICT
         DO NOTHING
         """,
         dummy_id=result.dummy_id,
@@ -866,8 +866,7 @@ def test_postgresql_connection_maker__sql_text(fixture_postgresql_test_proc, fix
                 :dummy_array_varchar,
                 :dummy_jsonb,
                 :dummy_json,
-                :dummy_unique_string)
-        ON CONFLICT
+                :dummy_unique_string) ON CONFLICT
         DO NOTHING
         """,
         dummy_char=result.dummy_char,
@@ -892,7 +891,7 @@ def test_postgresql_connection_maker__sql_text(fixture_postgresql_test_proc, fix
 
     with maker.make_session() as session:
         # PK violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             maker.execute(
                 # language=postgresql
                 """
@@ -958,7 +957,7 @@ def test_postgresql_connection_maker__sql_text(fixture_postgresql_test_proc, fix
 
     with maker.make_session() as session:
         # Unique index violation, which causes ``IntegrityError``
-        with pytest.raises(IntegrityError):
+        with pytest.raises(sa_exc.IntegrityError):
             maker.execute(
                 # language=postgresql
                 """
